RegionMapping

Struct RegionMapping 

pub struct RegionMapping {
    pub region: String,
    pub ns: Namespace,
    pub kind: HibernateRegionKind,
    pub mode: L2AccessMode,
}
A Hibernate region mapped to a HydraCache namespace.

Fields

region: String

Hibernate region name as configured by the app.

ns: Namespace

HydraCache namespace used on the W1 protocol.

kind: HibernateRegionKind

Hibernate region kind.

mode: L2AccessMode

Access mode and consistency contract.

Implementations

Source

impl RegionMapping

pub fn new( region: impl Into<String>, ns: Namespace, kind: HibernateRegionKind, mode: L2AccessMode, ) -> Result<Self, ClientProtocolError>

Build an explicit region mapping.

pub fn from_region( region: impl Into<String>, kind: HibernateRegionKind, mode: L2AccessMode, ) -> Result<Self, ClientProtocolError>

Build the default namespace mapping for a Hibernate region.

pub const fn consistency_mapping(&self) -> L2ConsistencyMapping

Return the consistency mapping for this region.

pub fn client_context(&self) -> ClientContext

Return a W1 request context for this region.

pub fn key<I, S>( &self, segments: I, ) -> Result<StructuredKey, ClientProtocolError>
where I: IntoIterator<Item = S>, S: Into<String>,

Build a namespaced structured key for this Hibernate region.

pub fn get(&self, key: StructuredKey) -> ClientRequest

Build a W1 get request for this region.

pub fn put( &self, key: StructuredKey, value: Vec<u8>, ttl_ms: Option<u64>, ) -> ClientRequest

Build a W1 put request for this region.

pub fn invalidate(&self, key: StructuredKey) -> ClientRequest

Build a W1 invalidation request for this region.

pub fn evict_region(&self) -> ClientRequest

Build a W1 region eviction request for this region’s namespace.