pub enum JavaMapOperation {
Get,
Put,
PutIfAbsent,
Remove,
ContainsKey,
GetAll,
PutAll,
Invalidate,
ClearNamespace,
EvictRegion,
}Expand description
Java map facade operation exposed by the migration toolkit.
Variants
Get
HydraCacheMap.get.
Put
HydraCacheMap.put.
PutIfAbsent
HydraCacheMap.putIfAbsent.
Remove
HydraCacheMap.remove.
ContainsKey
HydraCacheMap.containsKey.
GetAll
HydraCacheMap.getAll.
PutAll
HydraCacheMap.putAll.
Invalidate
Key invalidation.
ClearNamespace
Namespace clear for the map.
EvictRegion
Region/namespace eviction.
Implementations
Sourceimpl JavaMapOperation
impl JavaMapOperation
Sourcepub const fn protocol_family(self) -> JavaMapProtocolFamily
pub const fn protocol_family(self) -> JavaMapProtocolFamily
Return the protocol family that backs this facade operation.