pub struct EntryListenerContract {
pub coalesced: bool,
pub bounded_buffer: bool,
pub lag_drop_counter: bool,
pub business_event_log: bool,
}Expand description
Executable contract for W6 listener semantics.
Fields
coalesced: boolSignals may be coalesced and are not a complete event history.
bounded_buffer: boolDelivery uses bounded buffers.
lag_drop_counter: boolSlow listeners are dropped/reported through lag counters.
business_event_log: boolThis surface must not be used as a business event log.
Implementations
Sourceimpl EntryListenerContract
impl EntryListenerContract
Sourcepub const fn cache_signal() -> Self
pub const fn cache_signal() -> Self
Return the shipped W6 listener contract.