pub struct RegionMapping {
pub region: String,
pub ns: Namespace,
pub kind: HibernateRegionKind,
pub mode: L2AccessMode,
}Expand description
A Hibernate region mapped to a HydraCache namespace.
Fields
region: StringHibernate region name as configured by the app.
ns: NamespaceHydraCache namespace used on the W1 protocol.
kind: HibernateRegionKindHibernate region kind.
mode: L2AccessModeAccess mode and consistency contract.
Implementations
Sourceimpl RegionMapping
impl RegionMapping
Sourcepub fn new(
region: impl Into<String>,
ns: Namespace,
kind: HibernateRegionKind,
mode: L2AccessMode,
) -> Result<Self, ClientProtocolError>
pub fn new( region: impl Into<String>, ns: Namespace, kind: HibernateRegionKind, mode: L2AccessMode, ) -> Result<Self, ClientProtocolError>
Build an explicit region mapping.
Sourcepub fn from_region(
region: impl Into<String>,
kind: HibernateRegionKind,
mode: L2AccessMode,
) -> Result<Self, ClientProtocolError>
pub fn from_region( region: impl Into<String>, kind: HibernateRegionKind, mode: L2AccessMode, ) -> Result<Self, ClientProtocolError>
Build the default namespace mapping for a Hibernate region.
Sourcepub const fn consistency_mapping(&self) -> L2ConsistencyMapping
pub const fn consistency_mapping(&self) -> L2ConsistencyMapping
Return the consistency mapping for this region.
Sourcepub fn client_context(&self) -> ClientContext
pub fn client_context(&self) -> ClientContext
Return a W1 request context for this region.
Sourcepub fn key<I, S>(
&self,
segments: I,
) -> Result<StructuredKey, ClientProtocolError>
pub fn key<I, S>( &self, segments: I, ) -> Result<StructuredKey, ClientProtocolError>
Build a namespaced structured key for this Hibernate region.
Sourcepub fn get(&self, key: StructuredKey) -> ClientRequest
pub fn get(&self, key: StructuredKey) -> ClientRequest
Build a W1 get request for this region.
Sourcepub fn put(
&self,
key: StructuredKey,
value: Vec<u8>,
ttl_ms: Option<u64>,
) -> ClientRequest
pub fn put( &self, key: StructuredKey, value: Vec<u8>, ttl_ms: Option<u64>, ) -> ClientRequest
Build a W1 put request for this region.
Sourcepub fn invalidate(&self, key: StructuredKey) -> ClientRequest
pub fn invalidate(&self, key: StructuredKey) -> ClientRequest
Build a W1 invalidation request for this region.
Sourcepub fn evict_region(&self) -> ClientRequest
pub fn evict_region(&self) -> ClientRequest
Build a W1 region eviction request for this region’s namespace.